==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/TextClassificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ClassificationPrimaryMetrics
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.LogVerbosity
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Text Classification task in AutoML NLP vertical.
 * NLP - Natural Language Processing.
 * @property featurizationSettings Featurization inputs needed for AutoML job.
 * @property limitSettings Execution constraints for AutoMLJob.
 * @property logVerbosity Log verbosity for the job.
 * @property primaryMetric Primary metric for Text-Classification task.
 * @property targetColumnName Target column name: This is prediction values column.
 * Also known as label column name in context of classification tasks.
 * @property taskType AutoMLJob Task type.
 * Expected value is 'TextClassification'.
 * @property trainingData [Required] Training data input.
 * @property validationData Validation data inputs.
 */
public data class TextClassificationArgs(
    public val featurizationSettings: Output<NlpVerticalFeaturizationSettingsArgs>? = null,
    public val limitSettings: Output<NlpVerticalLimitSettingsArgs>? = null,
    public val logVerbosity: Output<Either<String, LogVerbosity>>? = null,
    public val primaryMetric: Output<Either<String, ClassificationPrimaryMetrics>>? = null,
    public val targetColumnName: Output<String>? = null,
    public val taskType: Output<String>,
    public val trainingData: Output<MLTableJobInputArgs>,
    public val validationData: Output<MLTableJobInputArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs.builder()
            .featurizationSettings(
                featurizationSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .limitSettings(limitSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .logVerbosity(
                logVerbosity?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .primaryMetric(
                primaryMetric?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .targetColumnName(targetColumnName?.applyValue({ args0 -> args0 }))
            .taskType(taskType.applyValue({ args0 -> args0 }))
            .trainingData(trainingData.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .validationData(
                validationData?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [TextClassificationArgs].
 */
@PulumiTagMarker
public class TextClassificationArgsBuilder internal constructor() {
    private var featurizationSettings: Output<NlpVerticalFeaturizationSettingsArgs>? = null

    private var limitSettings: Output<NlpVerticalLimitSettingsArgs>? = null

    private var logVerbosity: Output<Either<String, LogVerbosity>>? = null

    private var primaryMetric: Output<Either<String, ClassificationPrimaryMetrics>>? = null

    private var targetColumnName: Output<String>? = null

    private var taskType: Output<String>? = null

    private var trainingData: Output<MLTableJobInputArgs>? = null

    private var validationData: Output<MLTableJobInputArgs>? = null

    /**
     * @param value Featurization inputs needed for AutoML job.
     */
    @JvmName("wrvaxmgtqwknxlmb")
    public suspend fun featurizationSettings(`value`: Output<NlpVerticalFeaturizationSettingsArgs>) {
        this.featurizationSettings = value
    }

    /**
     * @param value Execution constraints for AutoMLJob.
     */
    @JvmName("ebekgvjquwverxbo")
    public suspend fun limitSettings(`value`: Output<NlpVerticalLimitSettingsArgs>) {
        this.limitSettings = value
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("atdocxjqihhgnsbq")
    public suspend fun logVerbosity(`value`: Output<Either<String, LogVerbosity>>) {
        this.logVerbosity = value
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("kttlmxyvacgxmeat")
    public suspend fun primaryMetric(`value`: Output<Either<String, ClassificationPrimaryMetrics>>) {
        this.primaryMetric = value
    }

    /**
     * @param value Target column name: This is prediction values column.
     * Also known as label column name in context of classification tasks.
     */
    @JvmName("eygnbiwgmrehxpgn")
    public suspend fun targetColumnName(`value`: Output<String>) {
        this.targetColumnName = value
    }

    /**
     * @param value AutoMLJob Task type.
     * Expected value is 'TextClassification'.
     */
    @JvmName("idewuxgalsgfkpgu")
    public suspend fun taskType(`value`: Output<String>) {
        this.taskType = value
    }

    /**
     * @param value [Required] Training data input.
     */
    @JvmName("rhnfbfhknwrncwex")
    public suspend fun trainingData(`value`: Output<MLTableJobInputArgs>) {
        this.trainingData = value
    }

    /**
     * @param value Validation data inputs.
     */
    @JvmName("iagmuovscpaogpls")
    public suspend fun validationData(`value`: Output<MLTableJobInputArgs>) {
        this.validationData = value
    }

    /**
     * @param value Featurization inputs needed for AutoML job.
     */
    @JvmName("igfdnrjawdacmwsn")
    public suspend fun featurizationSettings(`value`: NlpVerticalFeaturizationSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.featurizationSettings = mapped
    }

    /**
     * @param argument Featurization inputs needed for AutoML job.
     */
    @JvmName("gywmayqrxuipvdah")
    public suspend
    fun featurizationSettings(argument: suspend NlpVerticalFeaturizationSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NlpVerticalFeaturizationSettingsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.featurizationSettings = mapped
    }

    /**
     * @param value Execution constraints for AutoMLJob.
     */
    @JvmName("tvlgjisxqkiurrwk")
    public suspend fun limitSettings(`value`: NlpVerticalLimitSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.limitSettings = mapped
    }

    /**
     * @param argument Execution constraints for AutoMLJob.
     */
    @JvmName("iumoqpdrrcalkayr")
    public suspend
    fun limitSettings(argument: suspend NlpVerticalLimitSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NlpVerticalLimitSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.limitSettings = mapped
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("xcglwgwvfbxqsyjl")
    public suspend fun logVerbosity(`value`: Either<String, LogVerbosity>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logVerbosity = mapped
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("ikldwduniyhdjluj")
    public fun logVerbosity(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LogVerbosity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logVerbosity = mapped
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("qjyvmoeedplevpvf")
    public fun logVerbosity(`value`: LogVerbosity) {
        val toBeMapped = Either.ofRight<String, LogVerbosity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logVerbosity = mapped
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("bswhngkudcsuefcr")
    public suspend fun primaryMetric(`value`: Either<String, ClassificationPrimaryMetrics>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryMetric = mapped
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("dvprsswoyjoyxlih")
    public fun primaryMetric(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClassificationPrimaryMetrics>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.primaryMetric = mapped
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("kvuahhosgwmrvrew")
    public fun primaryMetric(`value`: ClassificationPrimaryMetrics) {
        val toBeMapped = Either.ofRight<String, ClassificationPrimaryMetrics>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.primaryMetric = mapped
    }

    /**
     * @param value Target column name: This is prediction values column.
     * Also known as label column name in context of classification tasks.
     */
    @JvmName("hfnicqhvtmnbvaor")
    public suspend fun targetColumnName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetColumnName = mapped
    }

    /**
     * @param value AutoMLJob Task type.
     * Expected value is 'TextClassification'.
     */
    @JvmName("cgyyedbwpbysidci")
    public suspend fun taskType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.taskType = mapped
    }

    /**
     * @param value [Required] Training data input.
     */
    @JvmName("emdxtmsoylkrhhpr")
    public suspend fun trainingData(`value`: MLTableJobInputArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trainingData = mapped
    }

    /**
     * @param argument [Required] Training data input.
     */
    @JvmName("bxbwnpcrhxsdssmi")
    public suspend fun trainingData(argument: suspend MLTableJobInputArgsBuilder.() -> Unit) {
        val toBeMapped = MLTableJobInputArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.trainingData = mapped
    }

    /**
     * @param value Validation data inputs.
     */
    @JvmName("edeyecmtloopsmrc")
    public suspend fun validationData(`value`: MLTableJobInputArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validationData = mapped
    }

    /**
     * @param argument Validation data inputs.
     */
    @JvmName("vgpnhmvdfhnigjfc")
    public suspend fun validationData(argument: suspend MLTableJobInputArgsBuilder.() -> Unit) {
        val toBeMapped = MLTableJobInputArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.validationData = mapped
    }

    internal fun build(): TextClassificationArgs = TextClassificationArgs(
        featurizationSettings = featurizationSettings,
        limitSettings = limitSettings,
        logVerbosity = logVerbosity,
        primaryMetric = primaryMetric,
        targetColumnName = targetColumnName,
        taskType = taskType ?: throw PulumiNullFieldException("taskType"),
        trainingData = trainingData ?: throw PulumiNullFieldException("trainingData"),
        validationData = validationData,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/TextClassificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ClassificationPrimaryMetrics
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.LogVerbosity
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Text Classification task in AutoML NLP vertical.
 * NLP - Natural Language Processing.
 * @property featurizationSettings Featurization inputs needed for AutoML job.
 * @property limitSettings Execution constraints for AutoMLJob.
 * @property logVerbosity Log verbosity for the job.
 * @property primaryMetric Primary metric for Text-Classification task.
 * @property targetColumnName Target column name: This is prediction values column.
 * Also known as label column name in context of classification tasks.
 * @property taskType AutoMLJob Task type.
 * Expected value is 'TextClassification'.
 * @property trainingData [Required] Training data input.
 * @property validationData Validation data inputs.
 */
public data class TextClassificationArgs(
    public val featurizationSettings: Output<NlpVerticalFeaturizationSettingsArgs>? = null,
    public val limitSettings: Output<NlpVerticalLimitSettingsArgs>? = null,
    public val logVerbosity: Output<Either<String, LogVerbosity>>? = null,
    public val primaryMetric: Output<Either<String, ClassificationPrimaryMetrics>>? = null,
    public val targetColumnName: Output<String>? = null,
    public val taskType: Output<String>,
    public val trainingData: Output<MLTableJobInputArgs>,
    public val validationData: Output<MLTableJobInputArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.TextClassificationArgs.builder()
            .featurizationSettings(
                featurizationSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .limitSettings(limitSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .logVerbosity(
                logVerbosity?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .primaryMetric(
                primaryMetric?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .targetColumnName(targetColumnName?.applyValue({ args0 -> args0 }))
            .taskType(taskType.applyValue({ args0 -> args0 }))
            .trainingData(trainingData.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .validationData(
                validationData?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [TextClassificationArgs].
 */
@PulumiTagMarker
public class TextClassificationArgsBuilder internal constructor() {
    private var featurizationSettings: Output<NlpVerticalFeaturizationSettingsArgs>? = null

    private var limitSettings: Output<NlpVerticalLimitSettingsArgs>? = null

    private var logVerbosity: Output<Either<String, LogVerbosity>>? = null

    private var primaryMetric: Output<Either<String, ClassificationPrimaryMetrics>>? = null

    private var targetColumnName: Output<String>? = null

    private var taskType: Output<String>? = null

    private var trainingData: Output<MLTableJobInputArgs>? = null

    private var validationData: Output<MLTableJobInputArgs>? = null

    /**
     * @param value Featurization inputs needed for AutoML job.
     */
    @JvmName("kbfkjjntsngiyyxb")
    public suspend fun featurizationSettings(`value`: Output<NlpVerticalFeaturizationSettingsArgs>) {
        this.featurizationSettings = value
    }

    /**
     * @param value Execution constraints for AutoMLJob.
     */
    @JvmName("ameenmsdwgcixrtx")
    public suspend fun limitSettings(`value`: Output<NlpVerticalLimitSettingsArgs>) {
        this.limitSettings = value
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("vmdjxoyeijvjbknu")
    public suspend fun logVerbosity(`value`: Output<Either<String, LogVerbosity>>) {
        this.logVerbosity = value
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("frxuivqirtdilmcu")
    public suspend fun primaryMetric(`value`: Output<Either<String, ClassificationPrimaryMetrics>>) {
        this.primaryMetric = value
    }

    /**
     * @param value Target column name: This is prediction values column.
     * Also known as label column name in context of classification tasks.
     */
    @JvmName("nyfygmbikcirqgay")
    public suspend fun targetColumnName(`value`: Output<String>) {
        this.targetColumnName = value
    }

    /**
     * @param value AutoMLJob Task type.
     * Expected value is 'TextClassification'.
     */
    @JvmName("cbxdsunbbwmtdqug")
    public suspend fun taskType(`value`: Output<String>) {
        this.taskType = value
    }

    /**
     * @param value [Required] Training data input.
     */
    @JvmName("idmnojilhvkibmrf")
    public suspend fun trainingData(`value`: Output<MLTableJobInputArgs>) {
        this.trainingData = value
    }

    /**
     * @param value Validation data inputs.
     */
    @JvmName("kwlmoiyykanrfilq")
    public suspend fun validationData(`value`: Output<MLTableJobInputArgs>) {
        this.validationData = value
    }

    /**
     * @param value Featurization inputs needed for AutoML job.
     */
    @JvmName("iacimvdircjerncu")
    public suspend fun featurizationSettings(`value`: NlpVerticalFeaturizationSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.featurizationSettings = mapped
    }

    /**
     * @param argument Featurization inputs needed for AutoML job.
     */
    @JvmName("iyltseboinieswnw")
    public suspend
    fun featurizationSettings(argument: suspend NlpVerticalFeaturizationSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NlpVerticalFeaturizationSettingsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.featurizationSettings = mapped
    }

    /**
     * @param value Execution constraints for AutoMLJob.
     */
    @JvmName("wpbenyxealldwwre")
    public suspend fun limitSettings(`value`: NlpVerticalLimitSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.limitSettings = mapped
    }

    /**
     * @param argument Execution constraints for AutoMLJob.
     */
    @JvmName("jfjiculspdobjniq")
    public suspend
    fun limitSettings(argument: suspend NlpVerticalLimitSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = NlpVerticalLimitSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.limitSettings = mapped
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("osqhhiyxjpphicvx")
    public suspend fun logVerbosity(`value`: Either<String, LogVerbosity>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logVerbosity = mapped
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("drbiimrnevyryjuo")
    public fun logVerbosity(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LogVerbosity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logVerbosity = mapped
    }

    /**
     * @param value Log verbosity for the job.
     */
    @JvmName("vobovuhpkhyncayk")
    public fun logVerbosity(`value`: LogVerbosity) {
        val toBeMapped = Either.ofRight<String, LogVerbosity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logVerbosity = mapped
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("eebhyehrkkcunmuf")
    public suspend fun primaryMetric(`value`: Either<String, ClassificationPrimaryMetrics>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryMetric = mapped
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("vfwjfwxjxlngyypp")
    public fun primaryMetric(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClassificationPrimaryMetrics>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.primaryMetric = mapped
    }

    /**
     * @param value Primary metric for Text-Classification task.
     */
    @JvmName("oedypqebpvlyxeuj")
    public fun primaryMetric(`value`: ClassificationPrimaryMetrics) {
        val toBeMapped = Either.ofRight<String, ClassificationPrimaryMetrics>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.primaryMetric = mapped
    }

    /**
     * @param value Target column name: This is prediction values column.
     * Also known as label column name in context of classification tasks.
     */
    @JvmName("hpledqxdabkdjlsh")
    public suspend fun targetColumnName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetColumnName = mapped
    }

    /**
     * @param value AutoMLJob Task type.
     * Expected value is 'TextClassification'.
     */
    @JvmName("nubbfalubgexdmef")
    public suspend fun taskType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.taskType = mapped
    }

    /**
     * @param value [Required] Training data input.
     */
    @JvmName("ualeuyquuufgvrfv")
    public suspend fun trainingData(`value`: MLTableJobInputArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trainingData = mapped
    }

    /**
     * @param argument [Required] Training data input.
     */
    @JvmName("ruheoidffyanpwbd")
    public suspend fun trainingData(argument: suspend MLTableJobInputArgsBuilder.() -> Unit) {
        val toBeMapped = MLTableJobInputArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.trainingData = mapped
    }

    /**
     * @param value Validation data inputs.
     */
    @JvmName("ergkaxlfgdawnbdf")
    public suspend fun validationData(`value`: MLTableJobInputArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validationData = mapped
    }

    /**
     * @param argument Validation data inputs.
     */
    @JvmName("mwqbgurhksrsvawu")
    public suspend fun validationData(argument: suspend MLTableJobInputArgsBuilder.() -> Unit) {
        val toBeMapped = MLTableJobInputArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.validationData = mapped
    }

    internal fun build(): TextClassificationArgs = TextClassificationArgs(
        featurizationSettings = featurizationSettings,
        limitSettings = limitSettings,
        logVerbosity = logVerbosity,
        primaryMetric = primaryMetric,
        targetColumnName = targetColumnName,
        taskType = taskType ?: throw PulumiNullFieldException("taskType"),
        trainingData = trainingData ?: throw PulumiNullFieldException("trainingData"),
        validationData = validationData,
    )
}
